@@ -33,7 +33,7 @@ create table `t_app_backup` (
   `version` int default null,
   `path` varchar(128) collate utf8mb4_general_ci default null,
   `description` varchar(255) collate utf8mb4_general_ci default null,
-  `create_time` datetime not null default current_timestamp comment 'create time',
+  `create_time` datetime default null comment 'create time',
   primary key (`id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
 
@@ -54,8 +54,8 @@ create table `t_flink_app` (
   `jar_check_sum` bigint default null,
   `main_class` varchar(255) collate utf8mb4_general_ci default null,
   `dependency` text collate utf8mb4_general_ci default null,
-  `args` text collate utf8mb4_general_ci,
-  `options` text collate utf8mb4_general_ci,
+  `args` longtext collate utf8mb4_general_ci,
+  `options` longtext collate utf8mb4_general_ci,
   `hot_params` text collate utf8mb4_general_ci,
   `user_id` bigint default null,
   `app_id` varchar(64) collate utf8mb4_general_ci default null,
@@ -74,7 +74,7 @@ create table `t_flink_app` (
   `cp_max_failure_interval` int default null,
   `cp_failure_rate_interval` int default null,
   `cp_failure_action` tinyint default null,
-  `dynamic_properties` text collate utf8mb4_general_ci,
+  `dynamic_properties` longtext collate utf8mb4_general_ci,
   `description` varchar(255) collate utf8mb4_general_ci default null,
   `resolve_order` tinyint default null,
   `k8s_rest_exposed_type` tinyint default null,
@@ -86,17 +86,17 @@ create table `t_flink_app` (
   `available_slot` int default null,
   `option_state` tinyint default null,
   `tracking` tinyint default null,
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   `option_time` datetime default null,
   `release` tinyint default 1,
   `build` tinyint default 1,
   `start_time` datetime default null,
   `end_time` datetime default null,
   `alert_id` bigint default null,
-  `k8s_pod_template` text collate utf8mb4_general_ci,
-  `k8s_jm_pod_template` text collate utf8mb4_general_ci,
-  `k8s_tm_pod_template` text collate utf8mb4_general_ci,
+  `k8s_pod_template` longtext collate utf8mb4_general_ci,
+  `k8s_jm_pod_template` longtext collate utf8mb4_general_ci,
+  `k8s_tm_pod_template` longtext collate utf8mb4_general_ci,
   `k8s_hadoop_integration` tinyint default 0,
   `flink_cluster_id` bigint default null,
   `ingress_template` text collate utf8mb4_general_ci,
@@ -120,7 +120,7 @@ create table `t_flink_config` (
   `version` int not null,
   `latest` tinyint not null default 0,
   `content` text collate utf8mb4_general_ci not null,
-  `create_time` datetime not null default current_timestamp comment 'create time',
+  `create_time` datetime default null comment 'create time',
   primary key (`id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
 
@@ -134,7 +134,7 @@ create table `t_flink_effective` (
   `app_id` bigint not null,
   `target_type` tinyint not null comment '1) config 2) flink sql',
   `target_id` bigint not null comment 'configid or sqlid',
-  `create_time` datetime not null default current_timestamp comment 'create time',
+  `create_time` datetime default null comment 'create time',
   primary key (`id`) using btree,
   unique key `un_effective_inx` (`app_id`,`target_type`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
@@ -153,7 +153,7 @@ create table `t_flink_env` (
   `flink_conf` text collate utf8mb4_general_ci not null comment 'flink-conf',
   `is_default` tinyint not null default 0 comment 'whether default version or not',
   `description` varchar(255) collate utf8mb4_general_ci default null comment 'description',
-  `create_time` datetime not null default current_timestamp comment 'create time',
+  `create_time` datetime default null comment 'create time',
   primary key (`id`) using btree,
   unique key `un_env_name` (`flink_name`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
@@ -184,7 +184,6 @@ create table `t_flink_project` (
   `id` bigint not null auto_increment,
   `team_id` bigint not null,
   `name` varchar(255) collate utf8mb4_general_ci default null,
-  `git_credential` tinyint not null,
   `url` varchar(255) collate utf8mb4_general_ci default null,
   `branches` varchar(64) collate utf8mb4_general_ci default null,
   `user_name` varchar(64) collate utf8mb4_general_ci default null,
@@ -197,8 +196,8 @@ create table `t_flink_project` (
   `last_build` datetime default null,
   `description` varchar(255) collate utf8mb4_general_ci default null,
   `build_state` tinyint default -1,
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   primary key (`id`) using btree,
   index `inx_team` (`team_id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
@@ -216,7 +215,7 @@ create table `t_flink_savepoint` (
   `path` varchar(255) collate utf8mb4_general_ci default null,
   `latest` tinyint not null default 1,
   `trigger_time` datetime default null,
-  `create_time` datetime not null default current_timestamp comment 'create time',
+  `create_time` datetime default null comment 'create time',
   primary key (`id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
 
@@ -232,7 +231,7 @@ create table `t_flink_sql` (
   `dependency` text collate utf8mb4_general_ci,
   `version` int default null,
   `candidate` tinyint not null default 1,
-  `create_time` datetime not null default current_timestamp comment 'create time',
+  `create_time` datetime default null comment 'create time',
   primary key (`id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
 
@@ -252,8 +251,8 @@ create table `t_menu` (
   `type` char(2) collate utf8mb4_general_ci default null comment 'type 0:menu 1:button',
   `display` tinyint collate utf8mb4_general_ci not null default 1 comment 'whether the menu is displayed',
   `order_num` int default null comment 'sort',
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   primary key (`menu_id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
 
@@ -270,7 +269,7 @@ create table `t_message` (
   `title` varchar(255) collate utf8mb4_general_ci default null,
   `context` text collate utf8mb4_general_ci,
   `is_read` tinyint default 0,
-  `create_time` datetime not null default current_timestamp comment 'create time',
+  `create_time` datetime default null comment 'create time',
   primary key (`id`) using btree,
   key `inx_mes_user` (`user_id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
@@ -284,8 +283,8 @@ create table `t_team` (
   `id` bigint not null auto_increment comment 'team id',
   `team_name` varchar(64) collate utf8mb4_general_ci not null comment 'team name',
   `description` varchar(255) collate utf8mb4_general_ci default null,
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   primary key (`id`) using btree,
   unique key `team_name_idx` (`team_name`) using btree
 ) engine = innodb default charset = utf8mb4 collate = utf8mb4_general_ci;
@@ -302,8 +301,8 @@ create table `t_variable` (
   `creator_id` bigint collate utf8mb4_general_ci not null comment 'user id of creator',
   `team_id` bigint collate utf8mb4_general_ci not null comment 'team id',
   `desensitization` tinyint not null default 0 comment '0 is no desensitization, 1 is desensitization, if set to desensitization, it will be replaced by * when displayed',
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   primary key (`id`) using btree,
   unique key `un_team_vcode_inx` (`team_id`,`variable_code`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
@@ -315,8 +314,8 @@ drop table if exists `t_role`;
 create table `t_role` (
   `role_id` bigint not null auto_increment comment 'user id',
   `role_name` varchar(64) collate utf8mb4_general_ci not null comment 'role name',
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   `description` varchar(255) collate utf8mb4_general_ci default null comment 'description',
   primary key (`role_id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
@@ -365,8 +364,8 @@ create table `t_user` (
   `login_type` tinyint default 0 comment 'login type 0:password 1:ldap',
   `last_team_id` bigint default null comment 'last team id',
   `status` char(1) collate utf8mb4_general_ci not null comment 'status 0:locked 1:active',
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   `last_login_time` datetime default null comment 'last login time',
   `sex` char(1) collate utf8mb4_general_ci default null comment 'gender 0:male 1:female 2:confidential',
   `avatar` varchar(128) collate utf8mb4_general_ci default null comment 'avatar',
@@ -385,8 +384,8 @@ create table `t_member` (
   `team_id` bigint not null comment 'team id',
   `user_id` bigint not null comment 'user id',
   `role_id` bigint not null comment 'role id',
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   primary key (`id`) using btree,
   unique key `un_user_team_role_inx` (`user_id`,`team_id`,`role_id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
@@ -406,7 +405,7 @@ create table `t_app_build_pipe`(
   `steps_status_ts` text,
   `error` text,
   `build_result` text,
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `modify_time` datetime default null comment 'modify time',
   primary key (`app_id`) using btree
 ) engine = innodb auto_increment=100000 default charset = utf8mb4 collate = utf8mb4_general_ci;
 
@@ -420,7 +419,7 @@ create table `t_flink_cluster` (
   `address` varchar(150) default null comment 'url address of jobmanager',
   `cluster_id` varchar(45) default null comment 'clusterid of session mode(yarn-session:application-id,k8s-session:cluster-id)',
   `cluster_name` varchar(128) not null comment 'cluster name',
-  `options` text comment 'json form of parameter collection ',
+  `options` longtext comment 'json form of parameter collection ',
   `yarn_queue` varchar(128) default null comment 'the yarn queue where the task is located',
   `execution_mode` tinyint not null default 1 comment 'k8s execution session mode(1:remote,3:yarn-session,5:kubernetes-session)',
   `version_id` bigint not null comment 'flink version id',
@@ -429,14 +428,14 @@ create table `t_flink_cluster` (
   `description` varchar(255) default null,
   `user_id` bigint default null,
   `flink_image` varchar(128) default null comment 'flink image',
-  `dynamic_properties` text comment 'allows specifying multiple generic configuration options',
+  `dynamic_properties` longtext comment 'allows specifying multiple generic configuration options',
   `k8s_rest_exposed_type` tinyint default 2 comment 'k8s export(0:loadbalancer,1:clusterip,2:nodeport)',
   `k8s_hadoop_integration` tinyint default 0,
   `k8s_conf` varchar(255) default null comment 'the path where the k8s configuration file is located',
   `resolve_order` int default null,
-  `exception` text comment 'exception information',
+  `exception` longtext comment 'exception information',
   `cluster_state` tinyint default 0 comment 'cluster status (0: created but not started, 1: started, 2: stopped)',
-  `create_time` datetime not null default current_timestamp comment 'create time',
+  `create_time` datetime default null comment 'create time',
   primary key (`id`,`cluster_name`),
   unique key `id` (`cluster_id`,`address`,`execution_mode`)
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
@@ -453,8 +452,8 @@ create table `t_access_token` (
   `expire_time` datetime default null comment 'expiration',
   `description` varchar(255) character set utf8mb4 collate utf8mb4_general_ci default null comment 'description',
   `status` tinyint default null comment '1:enable,0:disable',
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   primary key (`id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
 
@@ -474,8 +473,8 @@ create table `t_alert_config` (
   `we_com_params` varchar(255) collate utf8mb4_general_ci comment 'wechat params',
   `http_callback_params` text collate utf8mb4_general_ci comment 'http callback params',
   `lark_params` text collate utf8mb4_general_ci comment 'lark params',
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
   index `inx_alert_user` (`user_id`) using btree
 ) engine = innodb default charset = utf8mb4 collate = utf8mb4_general_ci;
 
@@ -489,8 +488,8 @@ CREATE TABLE `t_external_link` (
   `badge_name` varchar(64) collate utf8mb4_general_ci default null,
   `badge_color` varchar(64) collate utf8mb4_general_ci default null,
   `link_url` varchar(255) collate utf8mb4_general_ci default null,
-  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'create time',
-  `modify_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'modify time'
+  `create_time` datetime default null COMMENT 'create time',
+  `modify_time` datetime default null COMMENT 'modify time'
 ) engine = innodb default charset=utf8mb4 collate=utf8mb4_general_ci;
 
 -- ----------------------------
@@ -502,8 +501,8 @@ create table `t_yarn_queue` (
   `team_id` bigint not null comment 'team id',
   `queue_label` varchar(128) collate utf8mb4_general_ci not null comment 'queue label expression',
   `description` varchar(255) collate utf8mb4_general_ci default null comment 'description of the queue label',
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `create_time` datetime default null comment 'create time',
+  `modify_time` datetime default null comment 'modify time',
    unique key `unq_team_id_queue_label` (`team_id`, `queue_label`) using btree
 ) engine = innodb default charset = utf8mb4 collate = utf8mb4_general_ci;
 
