@@ -45,7 +45,8 @@ import com.baomidou.mybatisplus.annotation.TableField;
 import com.baomidou.mybatisplus.annotation.TableId;
 import com.baomidou.mybatisplus.annotation.TableName;
 import com.fasterxml.jackson.annotation.JsonIgnore;
-import lombok.Data;
+import lombok.Getter;
+import lombok.Setter;
 import lombok.SneakyThrows;
 import lombok.extern.slf4j.Slf4j;
 
@@ -61,7 +62,8 @@ import java.util.Optional;
 
 import static org.apache.streampark.console.core.enums.FlinkAppState.of;
 
-@Data
+@Getter
+@Setter
 @TableName("t_flink_app")
 @Slf4j
 public class Application implements Serializable {
@@ -118,24 +120,31 @@ public class Application implements Serializable {
   /** has restart count */
   private Integer restartCount;
 
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
   private Integer optionState;
 
   /** alert id */
   @TableField(updateStrategy = FieldStrategy.IGNORED)
   private Integer alertId;
 
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
   private String args;
   /** application module */
   private String module;
 
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
   private String options;
 
   @TableField(updateStrategy = FieldStrategy.IGNORED)
   private String hotParams;
 
   private Integer resolveOrder;
+
   private Integer executionMode;
+
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
   private String dynamicProperties;
+
   private Integer appType;
 
   /** determine if tracking status */
@@ -159,15 +168,19 @@ public class Application implements Serializable {
   @TableField(updateStrategy = FieldStrategy.IGNORED)
   private Date endTime;
 
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
   private Long duration;
 
   /** checkpoint max failure interval */
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
   private Integer cpMaxFailureInterval;
 
   /** checkpoint failure rate interval */
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
   private Integer cpFailureRateInterval;
 
   /** Actions triggered after X minutes failed Y times: 1: send alert 2: restart */
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
   private Integer cpFailureAction;
 
   /** overview */
@@ -184,8 +197,6 @@ public class Application implements Serializable {
   @TableField(updateStrategy = FieldStrategy.IGNORED)
   private Long flinkClusterId;
 
-  private String description;
-
   private Date createTime;
 
   private Date optionTime;
@@ -201,6 +212,7 @@ public class Application implements Serializable {
   private String k8sTmPodTemplate;
 
   private String ingressTemplate;
+
   private String defaultModeIngress;
 
   /** 1: cicd (build from csv) 2: upload (upload local jar job) */
@@ -209,8 +221,12 @@ public class Application implements Serializable {
   /** flink-hadoop integration on flink-k8s mode */
   private Boolean k8sHadoopIntegration;
 
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
   private String tags;
 
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
+  private String description;
+
   /** running job */
   private transient JobsOverview.Task overview;
 
@@ -239,6 +255,7 @@ public class Application implements Serializable {
   private transient String createTimeTo;
   private transient String backUpDescription;
   private transient String yarnQueue;
+  private transient String serviceAccount;
 
   /** Flink Web UI Url */
   private transient String flinkRestUrl;
@@ -248,22 +265,6 @@ public class Application implements Serializable {
 
   private transient AppControl appControl;
 
-  public String getIngressTemplate() {
-    return ingressTemplate;
-  }
-
-  public void setIngressTemplate(String ingressTemplate) {
-    this.ingressTemplate = ingressTemplate;
-  }
-
-  public String getDefaultModeIngress() {
-    return defaultModeIngress;
-  }
-
-  public void setDefaultModeIngress(String defaultModeIngress) {
-    this.defaultModeIngress = defaultModeIngress;
-  }
-
   public void setK8sNamespace(String k8sNamespace) {
     this.k8sNamespace =
         StringUtils.isBlank(k8sNamespace)
@@ -281,20 +282,34 @@ public class Application implements Serializable {
     this.tracking = shouldTracking(appState);
   }
 
-  public void setYarnQueueByHotParams() {
-    if (!(ExecutionMode.YARN_APPLICATION == this.getExecutionModeEnum()
-        || ExecutionMode.YARN_PER_JOB == this.getExecutionModeEnum())) {
+  public void setByHotParams() {
+    Map<String, Object> hotParamsMap = this.getHotParamsMap();
+    if (hotParamsMap.isEmpty()) {
       return;
     }
 
-    Map<String, Object> hotParamsMap = this.getHotParamsMap();
-    if (!hotParamsMap.isEmpty() && hotParamsMap.containsKey(ConfigConst.KEY_YARN_APP_QUEUE())) {
-      String yarnQueue = hotParamsMap.get(ConfigConst.KEY_YARN_APP_QUEUE()).toString();
-      String labelExpr =
-          Optional.ofNullable(hotParamsMap.get(ConfigConst.KEY_YARN_APP_NODE_LABEL()))
-              .map(Object::toString)
-              .orElse(null);
-      this.setYarnQueue(YarnQueueLabelExpression.of(yarnQueue, labelExpr).toString());
+    switch (getExecutionModeEnum()) {
+      case YARN_APPLICATION:
+      case YARN_PER_JOB:
+        // 1) set yarnQueue from hostParam
+        if (hotParamsMap.containsKey(ConfigConst.KEY_YARN_APP_QUEUE())) {
+          String yarnQueue = hotParamsMap.get(ConfigConst.KEY_YARN_APP_QUEUE()).toString();
+          String labelExpr =
+              Optional.ofNullable(hotParamsMap.get(ConfigConst.KEY_YARN_APP_NODE_LABEL()))
+                  .map(Object::toString)
+                  .orElse(null);
+          this.setYarnQueue(YarnQueueLabelExpression.of(yarnQueue, labelExpr).toString());
+        }
+        break;
+      case KUBERNETES_NATIVE_APPLICATION:
+        // 2) service-account.
+        Object serviceAccount = hotParamsMap.get(ConfigConst.KEY_KERBEROS_SERVICE_ACCOUNT());
+        if (serviceAccount != null) {
+          this.setServiceAccount(serviceAccount.toString());
+        }
+        break;
+      default:
+        break;
     }
   }
 
@@ -325,8 +340,7 @@ public class Application implements Serializable {
    * @return true: can start | false: can not start.
    */
   public boolean isCanBeStart() {
-    FlinkAppState state = FlinkAppState.of(getState());
-    switch (state) {
+    switch (getFlinkAppStateEnum()) {
       case ADDED:
       case CREATED:
       case FAILED:
@@ -344,7 +358,7 @@ public class Application implements Serializable {
   }
 
   public boolean shouldBeTrack() {
-    return shouldTracking(FlinkAppState.of(getState())) == 1;
+    return shouldTracking(getFlinkAppStateEnum()) == 1;
   }
 
   @JsonIgnore
@@ -465,7 +479,8 @@ public class Application implements Serializable {
   @JsonIgnore
   public boolean isApacheFlinkCustomCodeJob() {
     return DevelopmentMode.CUSTOM_CODE.getValue().equals(this.getJobType())
-        && getApplicationType() == ApplicationType.APACHE_FLINK;
+        && (getApplicationType() == ApplicationType.APACHE_FLINK
+            || getApplicationType() == ApplicationType.STREAMPARK_FLINK);
   }
 
   @JsonIgnore
@@ -482,6 +497,10 @@ public class Application implements Serializable {
     return this.getAppType() == ApplicationType.STREAMPARK_FLINK.getType();
   }
 
+  public boolean isKubernetesModeJob() {
+    return ExecutionMode.isKubernetesMode(this.getExecutionModeEnum());
+  }
+
   @JsonIgnore
   @SneakyThrows
   public MavenDependency getMavenDependency() {
@@ -569,6 +588,11 @@ public class Application implements Serializable {
     if (needFillYarnQueueLabel(executionModeEnum)) {
       hotParams.putAll(YarnQueueLabelExpression.getQueueLabelMap(appParam.getYarnQueue()));
     }
+    if (executionModeEnum == ExecutionMode.KUBERNETES_NATIVE_APPLICATION) {
+      if (StringUtils.isNotBlank(appParam.getServiceAccount())) {
+        hotParams.put(ConfigConst.KEY_KERBEROS_SERVICE_ACCOUNT(), appParam.getServiceAccount());
+      }
+    }
     if (!hotParams.isEmpty()) {
       this.setHotParams(JacksonUtils.write(hotParams));
     }
