@@ -20,12 +20,14 @@ package org.apache.streampark.console.core.entity;
 import com.baomidou.mybatisplus.annotation.IdType;
 import com.baomidou.mybatisplus.annotation.TableId;
 import com.baomidou.mybatisplus.annotation.TableName;
-import lombok.Data;
+import lombok.Getter;
+import lombok.Setter;
 import lombok.extern.slf4j.Slf4j;
 
 import java.util.Date;
 
-@Data
+@Getter
+@Setter
 @TableName("t_flink_log")
 @Slf4j
 public class ApplicationLog {
