@@ -28,14 +28,16 @@ import com.baomidou.mybatisplus.annotation.IdType;
 import com.baomidou.mybatisplus.annotation.TableId;
 import com.baomidou.mybatisplus.annotation.TableName;
 import com.fasterxml.jackson.annotation.JsonIgnore;
-import lombok.Data;
+import lombok.Getter;
+import lombok.Setter;
 
 import java.io.File;
 import java.io.Serializable;
 import java.util.Date;
 import java.util.Map;
 
-@Data
+@Getter
+@Setter
 @TableName("t_flink_env")
 public class FlinkEnv implements Serializable {
 
