@@ -25,12 +25,14 @@ import com.baomidou.mybatisplus.annotation.IdType;
 import com.baomidou.mybatisplus.annotation.TableField;
 import com.baomidou.mybatisplus.annotation.TableId;
 import com.baomidou.mybatisplus.annotation.TableName;
-import lombok.Data;
+import lombok.Getter;
+import lombok.Setter;
 
 import java.util.Base64;
 import java.util.Date;
 
-@Data
+@Getter
+@Setter
 @TableName("t_flink_sql")
 public class FlinkSql {
 
@@ -53,6 +55,7 @@ public class FlinkSql {
   private Integer candidate;
 
   private Date createTime;
+
   private transient boolean effective = false;
   /** sql diff */
   private transient boolean sqlDifference = false;
