@@ -22,7 +22,6 @@ import org.apache.streampark.common.util.CompletableFutureUtils;
 import org.apache.streampark.common.util.PropertiesUtils;
 import org.apache.streampark.common.util.ThreadUtils;
 import org.apache.streampark.common.util.Utils;
-import org.apache.streampark.console.base.domain.Constant;
 import org.apache.streampark.console.base.domain.RestRequest;
 import org.apache.streampark.console.base.exception.ApiAlertException;
 import org.apache.streampark.console.base.exception.InternalException;
@@ -44,7 +43,7 @@ import org.apache.streampark.console.core.service.ApplicationService;
 import org.apache.streampark.console.core.service.FlinkClusterService;
 import org.apache.streampark.console.core.service.FlinkEnvService;
 import org.apache.streampark.console.core.service.SavePointService;
-import org.apache.streampark.console.core.task.FlinkRESTAPIWatcher;
+import org.apache.streampark.console.core.task.FlinkAppHttpWatcher;
 import org.apache.streampark.flink.client.FlinkClient;
 import org.apache.streampark.flink.client.bean.SavepointResponse;
 import org.apache.streampark.flink.client.bean.TriggerSavepointRequest;
@@ -94,17 +93,18 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
 
   @Autowired private ApplicationLogService applicationLogService;
 
-  @Autowired private FlinkRESTAPIWatcher flinkRESTAPIWatcher;
+  @Autowired private FlinkAppHttpWatcher flinkAppHttpWatcher;
 
-  private final ExecutorService executorService =
+  private static final int CPU_NUM = Math.max(2, Runtime.getRuntime().availableProcessors());
+
+  private final ExecutorService flinkTriggerExecutor =
       new ThreadPoolExecutor(
-          Runtime.getRuntime().availableProcessors() * 5,
-          Runtime.getRuntime().availableProcessors() * 10,
+          CPU_NUM,
+          CPU_NUM,
           60L,
           TimeUnit.SECONDS,
-          new LinkedBlockingQueue<>(1024),
-          ThreadUtils.threadFactory("trigger-savepoint-executor"),
-          new ThreadPoolExecutor.AbortPolicy());
+          new LinkedBlockingQueue<>(),
+          ThreadUtils.threadFactory("streampark-flink-savepoint-trigger"));
 
   @Override
   public void expire(Long appId) {
@@ -265,15 +265,17 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
         if (!config.isEmpty()) {
           savepointPath = config.get(CheckpointingOptions.SAVEPOINT_DIRECTORY.key());
         }
-      } else {
-        // 3.2) At the yarn or k8s mode, then read the savepoint in flink-conf.yml in the bound
-        // flink
-        FlinkEnv flinkEnv = flinkEnvService.getById(application.getVersionId());
-        savepointPath =
-            flinkEnv.convertFlinkYamlAsMap().get(CheckpointingOptions.SAVEPOINT_DIRECTORY.key());
       }
     }
 
+    // 3.2) read the savepoint in flink-conf.yml in the bound
+    if (StringUtils.isBlank(savepointPath)) {
+      // flink
+      FlinkEnv flinkEnv = flinkEnvService.getById(application.getVersionId());
+      savepointPath =
+          flinkEnv.convertFlinkYamlAsMap().get(CheckpointingOptions.SAVEPOINT_DIRECTORY.key());
+    }
+
     return savepointPath;
   }
 
@@ -289,12 +291,12 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
     applicationLog.setOptionTime(new Date());
     applicationLog.setYarnAppId(application.getClusterId());
 
-    FlinkRESTAPIWatcher.addSavepoint(application.getId());
+    FlinkAppHttpWatcher.addSavepoint(application.getId());
 
     application.setOptionState(OptionState.SAVEPOINTING.getValue());
     application.setOptionTime(new Date());
     this.applicationService.updateById(application);
-    flinkRESTAPIWatcher.init();
+    flinkAppHttpWatcher.initialize();
 
     FlinkEnv flinkEnv = flinkEnvService.getById(application.getVersionId());
 
@@ -317,7 +319,8 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
             application.getK8sNamespace());
 
     CompletableFuture<SavepointResponse> savepointFuture =
-        CompletableFuture.supplyAsync(() -> FlinkClient.triggerSavepoint(request), executorService);
+        CompletableFuture.supplyAsync(
+            () -> FlinkClient.triggerSavepoint(request), flinkTriggerExecutor);
 
     handleSavepointResponseFuture(application, applicationLog, savepointFuture);
   }
@@ -351,7 +354,8 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
               application.setOptionState(OptionState.NONE.getValue());
               application.setOptionTime(new Date());
               applicationService.update(application);
-              flinkRESTAPIWatcher.init();
+              flinkAppHttpWatcher.cleanSavepoint(application);
+              flinkAppHttpWatcher.initialize();
             });
   }
 
@@ -422,8 +426,8 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
 
   @Override
   public IPage<SavePoint> page(SavePoint savePoint, RestRequest request) {
-    Page<SavePoint> page =
-        new MybatisPager<SavePoint>().getPage(request, "trigger_time", Constant.ORDER_DESC);
+    request.setSortField("trigger_time");
+    Page<SavePoint> page = MybatisPager.getPage(request);
     LambdaQueryWrapper<SavePoint> queryWrapper =
         new LambdaQueryWrapper<SavePoint>().eq(SavePoint::getAppId, savePoint.getAppId());
     return this.page(page, queryWrapper);
