@@ -18,7 +18,6 @@
 package org.apache.streampark.console.core.task;
 
 import org.apache.streampark.common.enums.ExecutionMode;
-import org.apache.streampark.common.util.ThreadUtils;
 import org.apache.streampark.console.core.entity.Application;
 import org.apache.streampark.console.core.enums.FlinkAppState;
 import org.apache.streampark.console.core.enums.OptionState;
@@ -37,15 +36,12 @@ import org.apache.streampark.flink.kubernetes.watcher.FlinkJobStatusWatcher;
 
 import com.google.common.eventbus.AllowConcurrentEvents;
 import com.google.common.eventbus.Subscribe;
+import lombok.extern.slf4j.Slf4j;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.context.annotation.Lazy;
 import org.springframework.stereotype.Component;
 
 import java.util.Date;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.LinkedBlockingQueue;
-import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
 
 import scala.Enumeration;
 
@@ -54,6 +50,7 @@ import static org.apache.streampark.console.core.enums.FlinkAppState.Bridge.toK8
 
 /** Event Listener for K8sFlinkTrackMonitor */
 @Component
+@Slf4j
 public class FlinkK8sChangeEventListener {
 
   @Lazy @Autowired private ApplicationService applicationService;
@@ -62,16 +59,6 @@ public class FlinkK8sChangeEventListener {
 
   @Lazy @Autowired private CheckpointProcessor checkpointProcessor;
 
-  private final ExecutorService executor =
-      new ThreadPoolExecutor(
-          Runtime.getRuntime().availableProcessors() * 5,
-          Runtime.getRuntime().availableProcessors() * 10,
-          20L,
-          TimeUnit.SECONDS,
-          new LinkedBlockingQueue<>(1024),
-          ThreadUtils.threadFactory("streampark-notify-executor"),
-          new ThreadPoolExecutor.AbortPolicy());
-
   /**
    * Catch FlinkJobStatusChangeEvent then storage it persistently to db. Actually update
    * org.apache.streampark.console.core.entity.Application records.
@@ -84,20 +71,21 @@ public class FlinkK8sChangeEventListener {
     TrackId trackId = event.trackId();
     // get pre application record
     Application app = applicationService.getById(trackId.appId());
-    if (app == null) {
+    if (app == null || FlinkAppState.isEndState(app.getState())) {
       return;
     }
+
     // update application record
     setByJobStatusCV(app, jobStatus);
     applicationService.persistMetrics(app);
 
+    FlinkAppState state = app.getFlinkAppStateEnum();
     // email alerts when necessary
-    FlinkAppState state = FlinkAppState.of(app.getState());
     if (FlinkAppState.FAILED.equals(state)
         || FlinkAppState.LOST.equals(state)
         || FlinkAppState.RESTARTING.equals(state)
         || FlinkAppState.FINISHED.equals(state)) {
-      executor.execute(() -> alertService.alert(app, state));
+      alertService.alert(app, state);
     }
   }
 
@@ -155,7 +143,7 @@ public class FlinkK8sChangeEventListener {
     // infer the final flink job state
     Enumeration.Value state =
         FlinkJobStatusWatcher.inferFlinkJobStateFromPersist(
-            jobStatus.jobState(), toK8sFlinkJobState(FlinkAppState.of(app.getState())));
+            jobStatus.jobState(), toK8sFlinkJobState(app.getFlinkAppStateEnum()));
 
     // corrective start-time / end-time / duration
     long preStartTime = app.getStartTime() != null ? app.getStartTime().getTime() : 0;
