@@ -56,7 +56,7 @@ public class AccessTokenServiceImpl extends ServiceImpl<AccessTokenMapper, Acces
   @Autowired private UserService userService;
 
   @Override
-  public RestResponse generateToken(Long userId, String expireTime, String description) {
+  public RestResponse create(Long userId, String expireTime, String description) {
     User user = userService.getById(userId);
     if (Objects.isNull(user)) {
       return RestResponse.success().put("code", 0).message("user not available");
@@ -74,7 +74,10 @@ public class AccessTokenServiceImpl extends ServiceImpl<AccessTokenMapper, Acces
     accessToken.setUserId(user.getUserId());
     accessToken.setDescription(description);
     accessToken.setExpireTime(DateUtils.stringToDate(jwtToken.getExpireAt()));
-    accessToken.setCreateTime(new Date());
+
+    Date date = new Date();
+    accessToken.setCreateTime(date);
+    accessToken.setModifyTime(date);
     accessToken.setStatus(AccessToken.STATUS_ENABLE);
 
     this.save(accessToken);
@@ -87,8 +90,8 @@ public class AccessTokenServiceImpl extends ServiceImpl<AccessTokenMapper, Acces
   }
 
   @Override
-  public IPage<AccessToken> findAccessTokens(AccessToken tokenParam, RestRequest request) {
-    Page<AccessToken> page = new MybatisPager<AccessToken>().getDefaultPage(request);
+  public IPage<AccessToken> page(AccessToken tokenParam, RestRequest request) {
+    Page<AccessToken> page = MybatisPager.getPage(request);
     this.baseMapper.page(page, tokenParam);
     List<AccessToken> records = page.getRecords();
     page.setRecords(records);
@@ -122,6 +125,7 @@ public class AccessTokenServiceImpl extends ServiceImpl<AccessTokenMapper, Acces
     AccessToken updateObj = new AccessToken();
     updateObj.setStatus(status);
     updateObj.setId(tokenId);
+    updateObj.setModifyTime(new Date());
     return RestResponse.success(this.updateById(updateObj));
   }
 
