@@ -3,11 +3,6 @@ export enum ProjectTypeEnum {
   SPARK = 2,
 }
 
-export enum GitCredentialEnum {
-  HTTPS = 1,
-  SSH = 2,
-}
-
 export enum CVSTypeEnum {
   GIT = 1,
   SVN = 2,
