@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 export default {
   id: 'ID',
-  appName: 'Application Name',
-  searchName: 'Name',
+  appName: 'Job Name',
+  searchName: 'Job Name',
   tags: 'Tags',
   owner: 'Owner',
   flinkVersion: 'Flink Version',
   duration: 'Duration',
   modifiedTime: 'Modified Time',
-  runStatus: 'Run Status',
-  releaseBuild: 'Release Status',
+  runStatus: 'Status',
+  releaseBuild: 'Release',
   jobType: 'Job Type',
   developmentMode: 'Development Mode',
   executionMode: 'Execution Mode',
@@ -44,8 +45,11 @@ export default {
   yarnQueue: 'Yarn Queue',
   mavenPom: 'Maven pom',
   uploadJar: 'Upload Jar',
+  useExisting: 'use existing',
+  reselect: 'reselect',
   kubernetesNamespace: 'Kubernetes Namespace',
   kubernetesClusterId: 'Kubernetes ClusterId',
+  kubernetesCluster: 'Kubernetes Cluster',
   flinkBaseDockerImage: 'Flink Base Docker Image',
   restServiceExposedType: 'Rest-Service Exposed Type',
   resourceFrom: 'Resource From',
@@ -65,14 +69,46 @@ export default {
   status: 'Run Status',
   startTime: 'Start Time',
   endTime: 'End Time',
+  runState: {
+    added: 'ADDED',
+    initializing: 'INITIALIZING',
+    created: 'CREATED',
+    starting: 'STARTING',
+    restarting: 'RESTARTING',
+    running: 'RUNNING',
+    failing: 'FAILING',
+    failed: 'FAILED',
+    lost: 'LOST',
+    cancelling: 'CANCELLING',
+    canceled: 'CANCELED',
+    finished: 'FINISHED',
+    suspended: 'SUSPENDED',
+    reconciling: 'RECONCILING',
+    mapping: 'MAPPING',
+    silent: 'SILENT',
+    terminated: 'TERMINATED',
+  },
+  releaseState: {
+    failed: 'FAILED',
+    success: 'SUCCESS',
+    waiting: 'WAITING',
+    releasing: 'RELEASING',
+    pending: 'PENDING',
+  },
+  clusterState: {
+    created: 'CREATED',
+    started: 'STARTED',
+    canceled: 'SHUTDOWN',
+    lost: 'LOST',
+  },
   release: {
-    releaseTitle: 'The current release of the application is in progress.',
+    releaseTitle: 'The current release of the job is in progress.',
     releaseDesc: 'are you sure you want to force another build',
-    releaseFail: 'release application failed,',
-    releasing: 'Current Application is releasing',
+    releaseFail: 'release job failed,',
+    releasing: 'Current job is releasing',
   },
   detail: {
-    detailTitle: 'Application Info',
+    detailTitle: 'Job Info',
     flinkWebUi: 'Flink Web UI',
     compareConfig: 'Compare Config',
     compareFlinkSql: 'Compare Flink SQL',
@@ -119,19 +155,27 @@ export default {
     },
   },
   view: {
-    buildTitle: 'Application releasing Progress',
+    buildTitle: 'Job releasing Progress',
     stepTitle: 'Steps Detail',
     errorLog: 'Error Log',
     errorSummary: 'Error Summary',
     errorStack: 'Error Stack',
-    logTitle: 'Start Log : Application Name [ {0} ]',
+    logTitle: 'Start Log : Job Name [ {0} ]',
     refreshTime: 'last refresh time',
     refresh: 'refresh',
-    start: 'Start Application',
-    stop: 'Stop application',
+    start: 'Start Job',
+    stop: 'Stop Job',
     savepoint: 'Trigger Savepoint',
-    recheck: 'the associated project has changed and this job need to be rechecked',
-    changed: 'the application has changed.',
+    fromSavepoint: 'From savepoint',
+    savepointTip: 'Restore the job from savepoint or latest checkpoint',
+    savepointInput: 'Specify the savepoint/checkpoint path',
+    savepointSwitch:
+      'Specify the savepoint/checkpoint path (Double-click to switch between "input" and "select")',
+    ignoreRestored: 'Ignore failed',
+    ignoreRestoredTip:
+      'ignore savepoint then cannot be restored, Same as：-allowNonRestoredState(-n)',
+    recheck: 'the associated project has changed and this job need to be release',
+    changed: 'the job has been updated',
   },
   pod: {
     choice: 'Choice',
@@ -159,18 +203,25 @@ export default {
     sqlCheck: 'SQL check error',
   },
   operation: {
-    edit: 'Edit Application',
-    release: 'Release Application',
+    edit: 'Edit Job',
+    release: 'Release Job',
     releaseDetail: 'Releasing Progress Detail',
-    start: 'Start Application',
-    cancel: 'Cancel Application',
+    start: 'Start Job',
+    cancel: 'Cancel Job',
     savepoint: 'Trigger Savepoint',
     detail: 'View Detail',
     startLog: 'See Flink Start log',
-    force: 'Forced Stop Application',
-    copy: 'Copy Application',
-    remapping: 'Remapping Application',
+    force: 'Forced Stop Job',
+    copy: 'Copy Job',
+    remapping: 'Remapping Job',
     deleteTip: 'Are you sure delete this job ?',
+    triggerSavePoint: 'Trigger savepoint',
+    enableSavePoint: 'Trigger savepoint before flink job cancel',
+    customSavepoint: 'Specify savepoint path to cancel the job ',
+    enableDrain: 'Send MAX_WATERMARK before taking the savepoint and stopping the pipeline',
+    invalidSavePoint: 'Custom savepoint path invalid: ',
+    canceling: 'The current job is canceling',
+    starting: 'The current job is starting',
   },
   dashboard: {
     availableTaskSlots: 'Available Task Slots',
@@ -214,15 +265,13 @@ export default {
     programJarIsRequiredMessage: 'Program Jar is required',
     useSysHadoopConf: 'Use System Hadoop Conf',
     flinkVersionIsRequiredMessage: 'Flink Version is required',
-    appNamePlaceholder: 'Please enter application Name',
-    appNameIsRequiredMessage: 'The application Name is required',
-    appNameNotUniqueMessage: 'The application Name is already exists, must be unique. ',
+    appNamePlaceholder: 'Please enter job Name',
+    appNameIsRequiredMessage: 'The job Name is required',
+    appNameNotUniqueMessage: 'The job Name is already exists, must be unique. ',
     appNameExistsInYarnMessage:
-      'The application name is already exists in YARN, cannot be repeated. Please check',
+      'The job name is already exists in YARN, cannot be repeated. Please check',
     appNameExistsInK8sMessage:
-      'The application name is already exists in Kubernetes,cannot be repeated. Please check',
-    appNameNotValid:
-      'The application name is invalid, must be (Chinese or English or "-" or "_"), two consecutive spaces cannot appear.Please check',
+      'The job name is already exists in Kubernetes,cannot be repeated. Please check',
     flinkClusterIsRequiredMessage: 'Flink Cluster is required',
     flinkSqlIsRequiredMessage: 'Flink SQL is required',
     tagsPlaceholder: 'Please enter tags,if more than one, separate them with commas(,)',
@@ -233,11 +282,20 @@ export default {
     totalMemoryOptionsPlaceholder: 'Please select the resource parameters to set',
     tmPlaceholder: 'Please select the resource parameters to set',
     yarnQueuePlaceholder: 'Please enter yarn queue label',
-    descriptionPlaceholder: 'Please enter description for this application',
+    descriptionPlaceholder: 'Please enter description for this job',
+    serviceAccountPlaceholder: 'Please enter kubernetes service-account, e.g: default',
     kubernetesNamespacePlaceholder: 'Please enter kubernetes Namespace, e.g: default',
     kubernetesClusterIdPlaceholder: 'Please enter Kubernetes clusterId',
-    kubernetesClusterIdRequire:
-      "lower case alphanumeric characters, '-', and must start and end with an alphanumeric character,and no more than 45 characters",
+    appNameValid: 'The job name is invalid',
+    appNameRole: 'The job name is invalid',
+    K8sSessionClusterIdRole: 'The K8s clusterId must follow the following rules:',
+    appNameK8sClusterIdRole:
+      'The current deployment mode is K8s Application mode, and the job name will be used as the clusterId in K8s. Therefore, the job name must follow the following rules:',
+    appNameK8sClusterIdRoleLength: 'must be no more than 45 characters',
+    appNameK8sClusterIdRoleRegexp:
+      'must only contain lowercase alphanumeric characters and "-"，The required format is [a-z]([-a-z0-9]*[a-z0-9])',
+    appNameRoleContent:
+      'must be (Chinese or English or "-" or "_"), two consecutive spaces cannot appear.Please check',
     kubernetesClusterIdIsRequiredMessage: 'Kubernetes clusterId is required',
     flinkImagePlaceholder:
       'Please enter the tag of Flink base docker image, such as: flink:1.13.0-scala_2.11-java8',
