@@ -34,14 +34,11 @@ export default {
     cvs: 'CVS',
     prvkeyPath: 'Private Key Path',
     prvkeyPathPlaceholder: 'private key path, e.g: ~/.ssh/id_rsa',
-    gitCredential: 'Connect Type',
-    gitCredentialPlaceholder: 'Git connection type, http/ssh',
     cvsPlaceholder: 'CVS',
     repositoryURL: 'Repository URL',
     repositoryURLPlaceholder: 'The Repository URL for this project',
     repositoryURLRequired: 'The repository URL is required',
-    httpChecked: 'The repository address must be a valid http(s) address',
-    gitChecked: 'The repository address must be a valid ssh address',
+    credentialError: 'The repository address must be a valid ssh or http(s) address',
     userName: 'UserName',
     userNamePlaceholder: 'UserName for this project',
     password: 'Password',
@@ -62,7 +59,6 @@ export default {
     projectNameIsRequiredMessage: 'Project Name is required',
     projectNameIsUniqueMessage: 'The Project Name is already exists. Please check',
     projectTypeIsRequiredMessage: 'Project Type is required',
-    gitCredentialIsRequiredMessage: 'Connect Type is required',
     cvsIsRequiredMessage: 'CVS is required',
     repositoryURLIsRequiredMessage: 'Repository URL is required',
     pomSpecifiesModuleMessage:
