@@ -40,16 +40,19 @@ export default {
   jmMemoryOptions: 'JM内存',
   tmMemoryOptions: 'TM内存',
   podTemplate: 'Kubernetes Pod 模板',
-  flinkCluster: 'Flink集群',
-  yarnQueue: 'Yarn队列',
+  flinkCluster: 'Flink 集群',
+  yarnQueue: 'Yarn 队列',
   mavenPom: 'maven pom',
   uploadJar: '上传依赖Jar文件',
   kubernetesNamespace: 'K8S命名空间',
   kubernetesClusterId: 'K8S ClusterId',
+  kubernetesCluster: 'Kubernetes Session Cluster',
   flinkBaseDockerImage: 'Flink基础docker镜像',
   restServiceExposedType: 'K8S服务对外类型',
   resourceFrom: '资源来源',
   uploadJobJar: '上传jar文件',
+  useExisting: '使用当前配置',
+  reselect: '重新选择配置',
   mainClass: '程序入口类',
   project: '项目',
   module: '模块',
@@ -64,12 +67,37 @@ export default {
   status: '运行状态',
   startTime: '启动时间',
   endTime: '结束时间',
+  runState: {
+    added: '新增作业',
+    initializing: '初始化',
+    created: '创建中',
+    starting: '启动中',
+    restarting: '重启中',
+    running: '运行中',
+    failing: '失败中',
+    failed: '作业失败',
+    lost: '作业失联',
+    cancelling: '取消中',
+    canceled: '已取消',
+    finished: '已完成',
+    suspended: '已暂停',
+    reconciling: '调整中',
+    mapping: '映射中',
+    silent: '沉默',
+    terminated: '终止',
+  },
   release: {
-    releaseTitle: '该应用程序的当前启动正在进行中.',
+    releaseTitle: '该作业正在启动中.',
     releaseDesc: '您确定要强制进行另一次构建吗',
     releaseFail: '发布作业失败',
     releasing: '当前作业正在发布中',
   },
+  clusterState: {
+    created: '新增',
+    started: '运行中',
+    canceled: '停止',
+    lost: '失联',
+  },
   detail: {
     detailTitle: '作业详情',
     flinkWebUi: 'Flink Web UI',
@@ -117,7 +145,7 @@ export default {
     },
   },
   view: {
-    buildTitle: '应用程序启动进度',
+    buildTitle: '作业启动进度',
     stepTitle: '步骤详情',
     errorLog: '错误日志',
     errorSummary: '错误摘要',
@@ -125,11 +153,17 @@ export default {
     logTitle: '启动日志 : 应用名称 [ {0} ]',
     refreshTime: '上次刷新时间',
     refresh: '刷新',
-    start: '开启应用',
+    start: '启动作业',
     stop: '停止应用',
     savepoint: '触发 Savepoint',
-    recheck: '关联的项目已更改，需要重新检查此作业',
-    changed: '应用程序已更改。',
+    recheck: '关联的项目已更新，需要重新发布此作业',
+    changed: '作业已更新',
+    fromSavepoint: 'Savepoint 恢复',
+    savepointTip: '作业从 savepoint 或 checkpoint 恢复状态',
+    savepointInput: '指定 savepoint/checkpoint 路径',
+    savepointSwitch: '指定 savepoint/checkpoint 路径 (双击切换"下拉框选择"或"手动输入")',
+    ignoreRestored: '忽略失败',
+    ignoreRestoredTip: '当状态恢复失败时跳过错误，作业继续运行, 同参数：-allowNonRestoredState(-n)',
   },
   pod: {
     choice: '选择',
@@ -169,6 +203,13 @@ export default {
     copy: '复制作业',
     remapping: '重新映射作业',
     deleteTip: '你确定要删除这个作业?',
+    triggerSavePoint: '触发 savepoint',
+    enableSavePoint: '在 Flink 作业取消之前触发 savepoint',
+    customSavepoint: '指定 savepoint 保存路径',
+    enableDrain: '在触发 savepoint 和停止作业之前发送 MAX_WATERMARK',
+    invalidSavePoint: 'savepoint 路径无效: ',
+    canceling: '当前作业正在停止中',
+    starting: '当前作业正在启动中',
   },
   dashboard: {
     availableTaskSlots: '可用的任务槽数',
@@ -183,16 +224,23 @@ export default {
     totalTaskManagerMemory: 'TaskManager总内存',
   },
   runStatusOptions: {
-    added: '新增',
+    added: '新增作业',
     starting: '启动中',
     running: '运行中',
-    failed: '失败',
+    failed: '作业失败',
+    lost: '作业失联',
     canceled: '已取消',
     finished: '已完成',
     suspended: '暂停',
-    lost: '丢失',
     silent: '静默',
-    terminated: '终止',
+    terminated: '作业终止',
+  },
+  releaseState: {
+    failed: '发布失败',
+    success: '发布成功',
+    waiting: '待发布',
+    releasing: '发布中',
+    pending: '待回滚',
   },
   addAppTips: {
     developmentModePlaceholder: '请选择开发模式',
@@ -214,11 +262,18 @@ export default {
     appNamePlaceholder: '请输入作业名称',
     appNameIsRequiredMessage: '作业名称必填',
     appNameNotUniqueMessage: '作业名称必须唯一, 输入的作业名称已经存在',
-    appNameExistsInYarnMessage: '应用程序名称已经在YARN集群中存在，不能重复。请检查',
-    appNameExistsInK8sMessage: '该应用程序名称已经在K8S集群中存在，不能重复。请检查',
-    appNameNotValid:
-      '应用程序名称无效。字符必须是(中文 或 英文 或 "-" 或 "_")，不能出现两个连续的空格，请检查',
-    flinkClusterIsRequiredMessage: 'Flink集群必填',
+    appNameExistsInYarnMessage: '该作业名称已经在YARN集群中存在，不能重复。请检查',
+    appNameExistsInK8sMessage: '该作业名称已经在K8S集群中存在，不能重复。请检查',
+    appNameValid: '作业名称不合法',
+    appNameRole: '作业必须遵循以下规则：',
+    K8sSessionClusterIdRole: 'K8S集群ID必要遵循以下规则:',
+    appNameK8sClusterIdRole:
+      '当前部署模式是 K8s Application模式，会将作业名称作为k8s的 clusterId，因此作业名称要遵循以下规则:',
+    appNameK8sClusterIdRoleLength: '不应超过 45 个字符',
+    appNameK8sClusterIdRoleRegexp:
+      '只能由小写字母、数字、字符、和"-" 组成，必须满足正则格式 [a-z]([-a-z0-9]*[a-z0-9])',
+    appNameRoleContent: '字符必须是(中文 或 英文 或 "-" 或 "_")，不能出现两个连续的空格',
+    flinkClusterIsRequiredMessage: 'Flink 集群必填',
     flinkSqlIsRequiredMessage: 'Flink SQL必填',
     tagsPlaceholder: '请输入标签，如果超过一个，用逗号（，）分隔',
     parallelismPlaceholder: '运行程序的并行度',
@@ -228,11 +283,10 @@ export default {
     totalMemoryOptionsPlaceholder: '请选择要设置的资源参数',
     tmPlaceholder: '请选择要设置的资源参数',
     yarnQueuePlaceholder: '请输入yarn队列标签名称',
-    descriptionPlaceholder: '请输入此应用程序的描述',
+    descriptionPlaceholder: '请输入此作业的描述',
+    serviceAccountPlaceholder: '请输入K8S服务账号(service-account)',
     kubernetesNamespacePlaceholder: '请输入K8S命名空间, 如: default',
     kubernetesClusterIdPlaceholder: '请选择K8S ClusterId',
-    kubernetesClusterIdRequire:
-      '小写字母、数字、“-”，并且必须以字母数字字符开头和结尾，并且不超过45个字符',
     kubernetesClusterIdIsRequiredMessage: 'K8S ClusterId必填',
     flinkImagePlaceholder: '请输入Flink基础docker镜像的标签,如:flink:1.13.0-scala_2.11-java8',
     flinkImageIsRequiredMessage: 'Flink基础docker镜像是必填的',
