@@ -228,7 +228,7 @@ export const useFlinkApplication = (openStartModal: Fn) => {
         return (
           <Form class="!pt-50px">
             <Form.Item
-              label="Application Name"
+              label="Job Name"
               labelCol={{ lg: { span: 7 }, sm: { span: 7 } }}
               wrapperCol={{ lg: { span: 16 }, sm: { span: 4 } }}
               validateStatus={unref(validateStatus)}
@@ -237,7 +237,7 @@ export const useFlinkApplication = (openStartModal: Fn) => {
             >
               <Input
                 type="text"
-                placeholder="New Application Name"
+                placeholder="New Job Name"
                 onInput={(e) => {
                   copyAppName = e.target.value;
                 }}
@@ -252,8 +252,8 @@ export const useFlinkApplication = (openStartModal: Fn) => {
         //1) check empty
         if (copyAppName == null) {
           validateStatus.value = 'error';
-          help = 'Sorry, Application Name cannot be empty';
-          return Promise.reject('copy application error');
+          help = 'Sorry, Job Name cannot be empty';
+          return Promise.reject('copy job error');
         }
         //2) check name
         const params = { jobName: copyAppName };
