@@ -39,7 +39,13 @@ import { handleConfTemplate } from '/@/api/flink/config';
 import { decodeByBase64 } from '/@/utils/cipher';
 import { useMessage } from '/@/hooks/web/useMessage';
 import { SelectValue } from 'ant-design-vue/lib/select';
-import { AppTypeEnum, CandidateTypeEnum, FailoverStrategyEnum } from '/@/enums/flinkEnum';
+import {
+  AppTypeEnum,
+  CandidateTypeEnum,
+  ClusterStateEnum,
+  ExecModeEnum,
+  FailoverStrategyEnum,
+} from '/@/enums/flinkEnum';
 import { useI18n } from '/@/hooks/web/useI18n';
 import { fetchYarnQueueList } from '/@/api/flink/setting/yarnQueue';
 import { ApiSelect } from '/@/components/Form';
@@ -261,6 +267,78 @@ export const renderYarnQueue = ({ model, field }: RenderCallbackParams) => {
   );
 };
 
+export const renderJobName = ({ model, field }: RenderCallbackParams) => {
+  return (
+    <div>
+      <Input
+        name="jobName"
+        placeholder={t('flink.app.addAppTips.appNamePlaceholder')}
+        value={model[field]}
+        onInput={(e: ChangeEvent) => (model[field] = e?.target?.value)}
+      />
+      <p class="conf-desc mt-10px">
+        <span class="note-info">
+          <Tag color="#2db7f5" class="tag-note">
+            {t('flink.app.noteInfo.note')}
+          </Tag>
+          {model.executionMode == ExecModeEnum.KUBERNETES_APPLICATION && (
+            <span>
+              {t('flink.app.addAppTips.appNameK8sClusterIdRole')}
+              <div>
+                <Tag color="orange"> 1.</Tag>
+                {t('flink.app.addAppTips.appNameK8sClusterIdRoleLength')}
+              </div>
+              <div>
+                <Tag color="orange"> 2.</Tag>
+                {t('flink.app.addAppTips.appNameK8sClusterIdRoleRegexp')}
+              </div>
+            </span>
+          )}
+
+          {model.executionMode != ExecModeEnum.KUBERNETES_APPLICATION && (
+            <span>
+              <span>{t('flink.app.addAppTips.appNameRole')}</span>
+              <span>{t('flink.app.addAppTips.appNameRoleContent')}</span>
+            </span>
+          )}
+        </span>
+      </p>
+    </div>
+  );
+};
+
+export const renderFlinkCluster = (clusters, { model, field }: RenderCallbackParams) => {
+  return (
+    <Select
+      placeholder={t('flink.app.flinkCluster')}
+      value={model[field]}
+      onChange={(value: any) => (model[field] = value)}
+    >
+      {clusters.map((item) => {
+        return (
+          <Select.Option key={item.id}>
+            {item.label}
+            <span style="margin-left: 50px;">
+              {item.state == ClusterStateEnum.CREATED && (
+                <Tag color="#108ee9">{t('flink.app.clusterState.created')}</Tag>
+              )}
+              {item.state == ClusterStateEnum.STARTED && (
+                <Tag color="#52c41a">{t('flink.app.clusterState.started')}</Tag>
+              )}
+              {item.state == ClusterStateEnum.CANCELED && (
+                <Tag color="#fa8c16">{t('flink.app.clusterState.canceled')}</Tag>
+              )}
+              {item.state == ClusterStateEnum.LOST && (
+                <Tag color="#333333">{t('flink.app.clusterState.lost')}</Tag>
+              )}
+            </span>
+          </Select.Option>
+        );
+      })}
+    </Select>
+  );
+};
+
 /* render memory option */
 export const renderDynamicProperties = ({ model, field }: RenderCallbackParams) => {
   return (
@@ -277,7 +355,6 @@ export const renderDynamicProperties = ({ model, field }: RenderCallbackParams)
           <Tag color="#2db7f5" class="tag-note">
             {t('flink.app.noteInfo.note')}
           </Tag>
-          {t('flink.app.noteInfo.dynamicProperties')}
           <a
             href="https://ci.apache.org/projects/flink/flink-docs-stable/ops/config.html"
             target="_blank"
@@ -440,7 +517,7 @@ export const renderSqlHistory = (
       if (!isCompareSelect) return false;
       return compareSQL.value.length == 2 && compareSQL.value.findIndex((i) => i === ver.id) === -1;
     };
-    console.log('flinkSqlHistory', flinkSqlHistory);
+
     return (flinkSqlHistory || []).map((ver) => {
       return (
         <Select.Option key={ver.id} disabled={isDisabled(ver)}>
