@@ -29,16 +29,15 @@ object IngressController extends Logger {
 
   private[this] val VERSION_REGEXP = "(\\d+\\.\\d+)".r
 
+  private lazy val clusterVersion = using(new DefaultKubernetesClient()) {
+    client => VERSION_REGEXP.findFirstIn(client.getVersion.getGitVersion).get.toDouble
+  }
+
   private lazy val ingressStrategy: IngressStrategy = {
-    using(new DefaultKubernetesClient()) {
-      client =>
-        val versionInfo = client.getVersion
-        val version = VERSION_REGEXP.findFirstIn(client.getVersion.getGitVersion).get.toDouble
-        if (version >= 1.19) {
-          new IngressStrategyV1()
-        } else {
-          new IngressStrategyV1beta1()
-        }
+    if (clusterVersion >= 1.19) {
+      new IngressStrategyV1()
+    } else {
+      new IngressStrategyV1beta1()
     }
   }
 
@@ -46,11 +45,11 @@ object IngressController extends Logger {
     ingressStrategy.configureIngress(domainName, clusterId, nameSpace)
   }
 
-  def ingressUrlAddress(
+  def getIngressUrl(
       nameSpace: String,
       clusterId: String,
       clusterClient: ClusterClient[_]): String = {
-    ingressStrategy.ingressUrlAddress(nameSpace, clusterId, clusterClient)
+    ingressStrategy.getIngressUrl(nameSpace, clusterId, clusterClient)
   }
 
   def prepareIngressTemplateFiles(buildWorkspace: String, ingressTemplates: String): String = {
