@@ -17,7 +17,7 @@
 
 package org.apache.streampark.flink.kubernetes.ingress
 
-import org.apache.streampark.common.conf.{ConfigConst, InternalConfigHolder, K8sFlinkConfig}
+import org.apache.streampark.common.conf.{InternalConfigHolder, K8sFlinkConfig}
 
 import io.fabric8.kubernetes.api.model.{OwnerReference, OwnerReferenceBuilder}
 import io.fabric8.kubernetes.client.DefaultKubernetesClient
@@ -28,10 +28,9 @@ import java.io.File
 
 trait IngressStrategy {
 
-  def ingressUrlAddress(
-      nameSpace: String,
-      clusterId: String,
-      clusterClient: ClusterClient[_]): String
+  lazy val ingressClass: String = InternalConfigHolder.get[String](K8sFlinkConfig.ingressClass)
+
+  def getIngressUrl(nameSpace: String, clusterId: String, clusterClient: ClusterClient[_]): String
 
   def configureIngress(domainName: String, clusterId: String, nameSpace: String): Unit
 
@@ -48,16 +47,11 @@ trait IngressStrategy {
   }
 
   def buildIngressAnnotations(clusterId: String, namespace: String): Map[String, String] = {
-    var annotations = Map(
+    Map(
       "nginx.ingress.kubernetes.io/rewrite-target" -> "/$2",
       "nginx.ingress.kubernetes.io/proxy-body-size" -> "1024m",
       "nginx.ingress.kubernetes.io/configuration-snippet" -> s"""rewrite ^(/$clusterId)$$ $$1/ permanent; sub_filter '<base href="./">' '<base href="/$namespace/$clusterId/">'; sub_filter_once off;"""
     )
-    val ingressClass = InternalConfigHolder.get[String](K8sFlinkConfig.ingressClass)
-    if (ingressClass.nonEmpty) {
-      annotations += ("kubernetes.io/ingress.class" -> ingressClass)
-    }
-    annotations
   }
 
   def buildIngressLabels(clusterId: String): Map[String, String] = {
