@@ -18,13 +18,15 @@ package org.apache.streampark.flink.core
 
 import org.apache.flink.kubernetes.kubeclient.FlinkKubeClient
 import org.apache.flink.kubernetes.kubeclient.resources.KubernetesService
+import org.apache.flink.kubernetes.kubeclient.resources.KubernetesService.ServiceType
 
 import java.util.Optional
 
-class FlinkKubernetesClient(kubeClient: FlinkKubeClient) extends FlinkKubernetesClientTrait(kubeClient) {
+class FlinkKubernetesClient(kubeClient: FlinkKubeClient)
+  extends FlinkKubernetesClientTrait(kubeClient) {
 
   override def getService(serviceName: String): Optional[KubernetesService] = {
-    kubeClient.getService(serviceName)
+    kubeClient.getService(ServiceType.REST_SERVICE, serviceName)
   }
 
 }
